<?php

/**
 * FaceBookPixel short summary.
 *
 * FaceBookPixel description.
 *
 * @version 1.0
 * @author Jacob.Hulse
 * @comapy Knight Shift Productions
 */
class KSPFaceBookPixel
{

    /**
     * Pixel identifier provided by Facebook on generation
     * @var string
     */
    private $PixelID = '';



    public function __construct() {
        add_action('wp_head',               array($this, 'insert_Main_Pixel'));
        add_action('wp_footer',             array($this, 'generate_Page_Events'));
        add_action('wp_enqueue_scripts',    array($this, 'Enqueue_Scripts'));
    }


    

    /**
     * Registers scripts used by this plugin on the front end only.
     * 
     * Hooked into the 'wp_enqueue_scripts' action.
     */
    function Enqueue_Scripts()
    {
        if (!is_admin()) {
            wp_deregister_script('jquery');  
            wp_register_script('jquery', 'https://ajax.googleapis.com/ajax/libs/jquery/2.1.4/jquery.min.js', FALSE, '2.1.4', TRUE);  
            wp_enqueue_script('jquery');

            wp_register_script('ksputilities.js', plugins_url('../inc/scripts/ksputilities.js', __FILE__), false, null, true);
        }
    }


    public function insert_Main_Pixel() {


        //Base Pixel from Plugin Settings
        $pixel = ksp_wp_facebook_pixel_get_plugin_option('facebook_pixel');
        if (empty($pixel)) return; //We got nothing Jim

        //Get our PixelID
        $re = "/fbq\\s*\\(\\s*('|\")init('|\")\\s*,\\s*('|\")(.*?)('|\")\\s*\\)\\s*;/"; 
        preg_match_all($re, $pixel, $matches);
        $this->PixelID = $matches[4][0];
        
        echo $pixel;
    }


    public function generate_Page_Events() {
        $prefix = PLUGIN_ID.'_metabox_';

        //Get Post Specific Pixel
        $page_event = get_post_meta( get_the_ID(), $prefix.'event', true );
        if (empty($page_event)) return; //We got nothing Jim

        /* 
         * Event Data JSON
         * JSON Update Code
         * Event Function Call
         * Event Image Tag (if no variable values)
         */
        $page_events = array();

        //Place in loop for multiple events on single page
        $event_data = get_post_meta( get_the_ID(), $prefix.'event_values', true );
        $page_events[] = $this->generate_Page_Event($page_event, $event_data);
        //End Loop
        
        wp_enqueue_script('ksputilities.js');
        $script = '<script>jQuery(document).ready(function () {'."\r\n";
        //$script = '<script>function t () {'."\r\n";   //WORKS BUT FUNCTION T MUST BE CALLED
        $noscript = '<noscript>';
        foreach ($page_events as $event)
        {
        	$script .= 
                     $event['jsonData']."\r\n"
                    .$event['jsonDataUpdate']."\r\n"
                    .$event['fbq']."\r\n";
            $noscript .= $event['image']."\r\n";
        }
        $script .= '});</script>';
        //$script .= '}jQuery(document).ready(function () { t(); });</script>';
        $noscript .= '</noscript>';
        echo $script;
        echo $noscript;
    }


    private function generate_Page_Event($page_event, $event_data) {
        $event = array();
        $event_json = '';
        $event_json_update = '';
        $event_fbq = '';
        $event_image = '';
        $GetImage = true;
        $image_data = '';
        

        //Post specific event key/value pairs
        if(!empty($event_data)) {
            

            $event_json = 'eventJSON = {';            
                
            foreach( $event_data as $event_keyvalue_pair ) {
                $key = $event_keyvalue_pair['key'];
                $value = $event_keyvalue_pair['value'];

                //Replace Query string values
                if (preg_match('/\\?.*\\?/', $value)) {
                    $event_json_update .= 'eventJSON.'.$key.' = getQueryStringValue("'.str_replace('?', '', $value).'");';
                    $value = '';
                    $GetImage = false;
                }

                //Replace Javascript Variable values
                if (preg_match('/%.*%/', $value)) {
                    $event_json_update .= 'eventJSON.'.$key.' = '.str_replace('%', '', $value).';';
                    $value = '';
                    $GetImage = false;
                }

                $event_json .= $key.":".kspu_QuoteString($value).",";
                $image_data .= '&amp;cd['.$key.']='.$value;
            }

            $event_json = rtrim($event_json, ",").'};';
        }
            
        $event_fbq = "fbq('track', '".$page_event."'";
        if(empty($event_json)) { 
            $event_fbq .= ");";

        } else {
            $event_fbq .= ", eventJSON);";

        }
        


        if($GetImage) { 
            //Generate img tag
            /*
             * <img height="1" width="1" style="display:none" src="https://www.facebook.com/tr?id=FB_PIXEL_ID&amp;ev=Purchase
             *      &amp;cd[currency]=EUR
             *      &amp;cd[value]=15.20" />
             */

            $event_image = '<img height="1" width="1" style="display:none" src="https://www.facebook.com/tr?id='.$this->PixelID.'&amp;ev='.$page_event.$image_data.'" />';
        }

        $event['jsonData'] = $event_json;
        $event['jsonDataUpdate'] = $event_json_update;
        $event['fbq'] = $event_fbq;
        $event['image'] = $event_image;
        return $event;

    }




}
$kspFBPixel = new KSPFaceBookPixel();

