<?php
/**
 * KSP Facebook Pixel Plugin Settings
 * @version 0.1.0
 */
class ksp_wp_facebook_pixel_Plugin_Settings {
    /**
     * Option key, and option page slug
     * @var string
     */
	private $key = PLUGIN_OPTIONS;

	/**
     * Settings page metabox id
     * @var string
     */
	private $metabox_id = '';//PLUGIN_ID.'_option_metabox';

	/**
     * Settings Page title
     * @var string
     */
	protected $title = '';

	/**
     * Settings Page hook
     * @var string
     */
	protected $options_page = '';

    /**
     * Settings page header.  Displayed below title.
     * @var string
     */
    protected $options_page_header = '';

	/**
     * Constructor
     * @since 0.1.0
     */
	public function __construct() {
		$this->metabox_id = PLUGIN_ID.'_option_metabox';

		// Set our title & header
		$this->title = __( 'Facebook Pixel Settings', PLUGIN_ID );
        //$this->options_page_header = __('This page defines the global settings for the Facebook Pixel Plugin.', PLUGIN_ID );
	}

	/**
     * Initiate our hooks
     * @since 0.1.0
     */
	public function hooks() {
		add_action( 'admin_init', array( $this, 'init' ) );
		add_action( 'admin_menu', array( $this, 'add_options_page' ) );
		add_action( 'cmb2_admin_init', array( $this, 'add_options_page_metabox' ) );
		add_filter( 'cmb2_override_option_get_'. $this->key, array( $this, 'get_override' ), 10, 2 );
		add_filter( 'cmb2_override_option_save_'. $this->key, array( $this, 'update_override' ), 10, 2 );
	}

	/**
     * Register our setting to WP
     * @since  0.1.0
     */
	public function init() {
		register_setting( $this->key, $this->key );
	}

	/**
     * Add menu options page
     * @since 0.1.0
     */
	public function add_options_page() {
        $this->options_page = add_options_page( $this->title, $this->title, 'administrator', $this->key, array( $this, 'admin_page_display' ) );
		// add_action( "admin_head-{$this->options_page}", array( $this, 'enqueue_js' ) );
		// Include CMB CSS in the head to avoid FOUC
		add_action( "admin_print_styles-{$this->options_page}", array( 'CMB2_hookup', 'enqueue_cmb_css' ) );
	}

	/**
     * Admin page markup. Mostly handled by CMB2
     * @since  0.1.0
     */
	public function admin_page_display() {
		?><div class="wrap cmb2-options-page <?php echo $this->key; ?>">
			<h2><?php echo esc_html( get_admin_page_title() ); ?></h2>
            <h3><?php echo $this->options_page_header; ?></h3>
			<?php cmb2_metabox_form( $this->metabox_id, $this->key ); ?>
		</div><?php
	}

	/**
     * Add the options metabox to the array of metaboxes
     * @since  0.1.0
     */
	function add_options_page_metabox() {
		// hook in our save notices
		add_action( "cmb2_save_options-page_fields_{$this->metabox_id}", array( $this, 'settings_notices' ), 10, 2 );
		$cmb = new_cmb2_box( array(
			'id'         => $this->metabox_id,
			'hookup'     => false,
			'cmb_styles' => false,
			'show_on'    => array(
				'key'   => 'options-page',
				'value' => array( $this->key, )
			),
		) );

        $cmb->add_field( array(
			'name' => __( 'Facebook Pixel Code', PLUGIN_ID ),
			'desc' => __( 'Please enter the entire code snippet provided by Facebook<br />beginning with "'.esc_html('<!--').' Facebook Pixel Code -->"<br />ending with "'.esc_html('<!--').' End Facebook Pixel Code -->"<br />and everything in between.', PLUGIN_ID ),
			'id'   => 'facebook_pixel',
			'type' => 'textarea_code',
            'default' => 
"<!-- Facebook Pixel Code -->
<script>
!function(f,b,e,v,n,t,s){if(f.fbq)return;n=f.fbq=function(){n.callMethod?
n.callMethod.apply(n,arguments):n.queue.push(arguments)};if(!f._fbq)f._fbq=n;
n.push=n;n.loaded=!0;n.version='2.0';n.queue=[];t=b.createElement(e);t.async=!0;
t.src=v;s=b.getElementsByTagName(e)[0];s.parentNode.insertBefore(t,s)}(window,
document,'script','//connect.facebook.net/en_US/fbevents.js');

fbq('init', 'xxxx');
fbq('track', \"PageView\");</script>
<noscript><img height=\"1\" width=\"1\" style=\"display:none\"
src=\"https://www.facebook.com/tr?id=xxxx&ev=PageView&noscript=1\"
/></noscript>
<!-- End Facebook Pixel Code -->",
		) );

	}

	/**
     * Register settings notices for display
     *
     * @since  0.1.0
     * @param  int   $object_id Option key
     * @param  array $updated   Array of updated fields
     * @return void
     */
	public function settings_notices( $object_id, $updated ) {
		if ( $object_id !== $this->key || empty( $updated ) ) {
			return;
		}
		add_settings_error( $this->key . '-notices', '', __( 'Settings updated.', PLUGIN_ID ), 'updated' );
		settings_errors( $this->key . '-notices' );
	}

	/**
     * Replaces get_option with get_site_option
     * @since  0.1.0
     */
	public function get_override( $test, $default = false ) {
		return get_site_option( $this->key, $default );
	}

	/**
     * Replaces update_option with update_site_option
     * @since  0.1.0
     */
	public function update_override( $test, $option_value ) {
		return update_site_option( $this->key, $option_value );
	}

	/**
     * Public getter method for retrieving protected/private variables
     * @since  0.1.0
     * @param  string  $field Field to retrieve
     * @return mixed          Field value or exception is thrown
     */
	public function __get( $field ) {
		// Allowed fields to retrieve
		if ( in_array( $field, array( 'key', 'metabox_id', 'title', 'options_page' ), true ) ) {
			return $this->{$field};
		}
		throw new Exception( 'Invalid property: ' . $field );
	}
}


/**
 * Helper function to get/return the ksp_wp_facebook_pixel_Plugin_Settings object
 * @since  0.1.0
 * @return ksp_wp_facebook_pixel_Plugin_Settings object
 */
function ksp_wp_facebook_pixel_Plugin_Settings() {
	static $object = null;
	if ( is_null( $object ) ) {
		$object = new ksp_wp_facebook_pixel_Plugin_Settings();
		$object->hooks();
	}
	return $object;
}

/**
 * Wrapper function around cmb2_get_option
 * @since  0.1.0
 * @param  string  $key Options array key
 * @return mixed        Option value
 */
function ksp_wp_facebook_pixel_get_plugin_option( $key = '' ) {
	return cmb2_get_option( ksp_wp_facebook_pixel_Plugin_Settings()->key, $key );
}

// Get it started
ksp_wp_facebook_pixel_Plugin_Settings();
