<?php
/**
 * Plugin Name: WP Facebook Pixel
 * Plugin URI: http://knightshiftproductions.azurewebsites.net/
 * Description: Adds the new Facebook Pixel to all pages automatically and allows you to add standard Facebook events on each page.
 * Version: 1.0.2
 * Author: Knight Shift Productions
 * Author URI: http://knightshiftproductions.azurewebsites.net/
 * License GPL2
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Requires at least: 4.0
 * Tested up to: 4.4
 */






/**
 * Define Plugin Constants
 */
define('PLUGIN_ID', 'ksp_wp_facebook_pixel', true);
define('PLUGIN_NAME', 'WP Facebook Pixel', true);
define('PLUGIN_VERSION', '1.0.0', true);

define('PLUGIN_OPTIONS', PLUGIN_ID.'_options');



/**
 * Silence is golden; exit if accessed directly
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}





/**
 * Bootstrap CMB2
 * No need to check versions or if CMB2 is already loaded... the init file does that already!
 *
 * Check to see if CMB2 exists, and either bootstrap it or add a notice that it is missing
 */
if ( file_exists( dirname( __FILE__ ) . '/inc/CMB2/init.php' ) ) {
	require_once 'inc/CMB2/init.php';
} else {
	add_action( 'admin_notices', 'cmb2_example_plugin_missing_cmb2' );
}


/**
 * Add an error notice to the dashboard if CMB2 is missing from the plugin
 *
 * @return void
 */
function cmb2_example_plugin_missing_cmb2() { ?>
    <div class="error">
	    <p><?php _e( 'CMB2 Example Plugin is missing CMB2!', 'cmb2-example-plugin' ); ?></p>
    </div>
<?php }


/**
 * Send Email to me when the plugin is activated.
 */
function ksp_wp_facebook_pixel_plugin_on_activate() {
    $current_user = wp_get_current_user();
    $headers = array('Content-Type: text/html; charset=UTF-8');
    $message = '<h1>'.PLUGIN_NAME.'</h1>
        The plugin was just activated!<br />
        <br />
        <dl>
            <dt><b>Server Name</b></dt><dd>'.site_url().'</dd>
            <dt><b>User:</b></dt><dd>'.$current_user->user_firstname.' '.$current_user->user_lastname.'</dd>
            <dt><b>User Email:</b></dt><dd>'.$current_user->user_email.'</dd>
        </dl>';

    wp_mail( 'jacobmhulse@gmail.com', 'KSP WP Facebook Pixel Activated', $message, $headers);
}
register_activation_hook( __FILE__, 'ksp_wp_facebook_pixel_plugin_on_activate' );


function ksp_wp_facebook_pixel_plugin_on_deactivation() {
    $current_user = wp_get_current_user();
    $headers = array('Content-Type: text/html; charset=UTF-8');
    $message = '<h1>'.PLUGIN_NAME.'</h1>
        The plugin was just deactivated!<br />
        <br />
        <dl>
            <dt><b>Server Name</b></dt><dd>'.site_url().'</dd>
            <dt><b>User:</b></dt><dd>'.$current_user->user_firstname.' '.$current_user->user_lastname.'</dd>
            <dt><b>User Email:</b></dt><dd>'.$current_user->user_email.'</dd>
        </dl>';

    wp_mail( 'jacobmhulse@gmail.com', 'KSP WP Facebook Pixel Deactivated', $message, $headers);
}
register_deactivation_hook( __FILE__, 'ksp_wp_facebook_pixel_plugin_on_deactivation' );

function ksp_wp_facebook_pixel_plugin_on_uninstall() {
    $current_user = wp_get_current_user();
    $headers = array('Content-Type: text/html; charset=UTF-8');
    $message = '<h1>'.PLUGIN_NAME.'</h1>
        The plugin was just uninstalled!<br />
        <br />
        <dl>
            <dt><b>Server Name</b></dt><dd>'.site_url().'</dd>
            <dt><b>User:</b></dt><dd>'.$current_user->user_firstname.' '.$current_user->user_lastname.'</dd>
            <dt><b>User Email:</b></dt><dd>'.$current_user->user_email.'</dd>
        </dl>';

    wp_mail( 'jacobmhulse@gmail.com', 'KSP WP Facebook Pixel Uninstalled', $message, $headers);
}
register_uninstall_hook( __FILE__, 'ksp_wp_facebook_pixel_plugin_on_uninstall' );




/**
 * Adds actions to Plugin listing on Plugins page.
 * 
 * Hooked to the 'plugin_action_links' filter.
 * @param array $actions 
 * @param string $plugin_file 
 * @return array
 */
function ksp_wp_facebook_pixel_add_action_plugin( $actions, $plugin_file ) 
{
	static $plugin;

	if (!isset($plugin))
		$plugin = plugin_basename(__FILE__);

	if ($plugin == $plugin_file) {
        $settings = array('settings' => '<a href="options-general.php?page='.PLUGIN_OPTIONS.'">' . __('Settings', 'General') . '</a>');
        $actions = array_merge($settings, $actions);
    }
    
    return $actions;
}
add_filter( 'plugin_action_links', 'ksp_wp_facebook_pixel_add_action_plugin', 10, 5 );




/**
 * Load plugin resources
 */
require_once 'inc/KSPUtilities.php';        //Always include this first
require_once 'framework/PluginOptions.php';
require_once 'framework/MetaBox.php';
require_once 'assets/KSPFaceBookPixel.php';    //Where all the magic happens







